Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrecht Van Lommel <brechtvanlommel@gmail.com>2015-11-23 23:42:17 +0300
committerBrecht Van Lommel <brechtvanlommel@gmail.com>2015-11-28 17:35:34 +0300
commit263f4cd3426f19eccde79f6eeeec758c03a234ac (patch)
tree9b548ce5b47a43f7baa9bc7680fc1f4bdb4e642b /source/blender/gpu/GPU_draw.h
parent34f51cd4983db8d47ac41f949e466a520fa2173d (diff)
OpenGL: rename GPU_enable_material to better indicate it's binding shaders.
Diffstat (limited to 'source/blender/gpu/GPU_draw.h')
-rw-r--r--source/blender/gpu/GPU_draw.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/source/blender/gpu/GPU_draw.h b/source/blender/gpu/GPU_draw.h
index 0992f8e9d21..ce30f7460a1 100644
--- a/source/blender/gpu/GPU_draw.h
+++ b/source/blender/gpu/GPU_draw.h
@@ -63,7 +63,7 @@ void GPU_state_init(void);
* - first the state is initialized by a particular object and
* it's materials
* - after this, materials can be quickly enabled by their number,
* GPU_enable_material returns 0 if drawing should be skipped
* - after drawing, the material must be disabled again */
void GPU_begin_object_materials(struct View3D *v3d, struct RegionView3D *rv3d,
@@ -71,8 +71,8 @@ void GPU_begin_object_materials(struct View3D *v3d, struct RegionView3D *rv3d,
void GPU_end_object_materials(void);
bool GPU_object_materials_check(void);
-int GPU_enable_material(int nr, void *attribs);
-void GPU_disable_material(void);
+int GPU_object_material_bind(int nr, void *attribs);
+void GPU_object_material_unbind(void);
void GPU_begin_dupli_object(struct DupliObject *dob);
void GPU_end_dupli_object(void);
@@ -63,7 +63,7 @@ void GPU_state_init(void);
* it's materials
* - after this, materials can be quickly enabled by their number,
- * GPU_enable_material returns 0 if drawing should be skipped
+ * GPU_object_material_bind returns 0 if drawing should be skipped
* - after drawing, the material must be disabled again */
void GPU_begin_object_materials(struct View3D *v3d, struct RegionView3D *rv3d,